<?php

namespace Islhd\Store\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Islhd\Store\Interfaces\StockRepositoryInterface;

class StockPublicController extends BaseController
{
    // use StockWorkflow;

    /**
     * Constructor.
     *
     * @param type \Islhd\Stock\Interfaces\StockRepositoryInterface $stock
     *
     * @return type
     */
    public function __construct(StockRepositoryInterface $stock)
    {
        $this->repository = $stock;
        parent::__construct();
    }

    /**
     * Show stock's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $stocks = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('store::stock.names'))
            ->view('store::public.stock.index')
            ->data(compact('stocks'))
            ->output();
    }


    /**
     * Show stock.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $stock = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($stock->name . trans('store::stock.name'))
            ->view('store::public.stock.show')
            ->data(compact('stock'))
            ->output();
    }

}
