<?php

namespace Islhd\Store\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Islhd\Store\Http\Requests\StoreRequest;
use Islhd\Store\Interfaces\StoreRepositoryInterface;
use Islhd\Store\Models\Store;
use Islhd\Store\Forms\Store as Form;

/**
 * APIController  class for store.
 */
class StoreAPIController extends BaseController
{

    /**
     * Initialize store resource controller.
     *
     * @param type StoreRepositoryInterface $store
     *
     * @return null
     */
    public function __construct(StoreRepositoryInterface $store)
    {
        parent::__construct();
        $this->repository = $store;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Islhd\Store\Repositories\Criteria\StoreResourceCriteria::class);
    }

    /**
     * Display a list of store.
     *
     * @return Response
     */
    public function index(StoreRequest $request)
    {
        return $this->repository
            ->setPresenter(\Islhd\Store\Repositories\Presenter\StorePresenter::class)
            ->paginate();
    }

    /**
     * Display store.
     *
     * @param Request $request
     * @param Model   $store
     *
     * @return Response
     */
    public function show(StoreRequest $request, Store $store)
    {
        return $store->setPresenter(\Islhd\Store\Repositories\Presenter\StoreListPresenter::class);
        ;
    }

    /**
     * Create new store.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(StoreRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('store::store.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('store/store/' . $store->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('store/store');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the store.
     *
     * @param Request $request
     * @param Model   $store
     *
     * @return Response
     */
    public function update(StoreRequest $request, Store $store)
    {
        try {
            $data = $request->all();

            $store->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('store::store.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('store/store/' . $store->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('store/store/' . $store->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the store.
     *
     * @param Model   $store
     *
     * @return Response
     */
    public function destroy(StoreRequest $request, Store $store)
    {
        try {
            $store->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('store::store.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('store/store/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('store/store/' . $store->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
