<?php

namespace Islhd\Store\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Islhd\Store\Interfaces\StoreRepositoryInterface;

class StorePublicController extends BaseController
{
    // use StoreWorkflow;

    /**
     * Constructor.
     *
     * @param type \Islhd\Store\Interfaces\StoreRepositoryInterface $store
     *
     * @return type
     */
    public function __construct(StoreRepositoryInterface $store)
    {
        $this->repository = $store;
        parent::__construct();
    }

    /**
     * Show store's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $stores = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('store::store.names'))
            ->view('store::public.store.index')
            ->data(compact('stores'))
            ->output();
    }


    /**
     * Show store.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $store = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($store->name . trans('store::store.name'))
            ->view('store::public.store.show')
            ->data(compact('store'))
            ->output();
    }

}
